aboutsummaryrefslogtreecommitdiffstats
path: root/openbsc/src/osmo-nitb
diff options
context:
space:
mode:
authorIvan Kluchnikov <kluchnikovi@gmail.com>2015-12-11 19:24:07 +0300
committerIvan Kluchnikov <kluchnikovi@gmail.com>2017-02-07 18:59:54 +0300
commitdb0e216845a7859bf878a891e2a210dbef6395df (patch)
tree0b8be144ed907f777298ec18c68328913f82c202 /openbsc/src/osmo-nitb
parent2d9f39ec43254589c6487698d067774199ae7bcd (diff)
msc: Implement 'remote-closed' authentication policy
This mode is modified version of 'remote' policy. Osmo-nitb uses remote subscription data only if the MS is activated in local HLR, otherwise osmo-nitb rejects subscriber.
Diffstat (limited to 'openbsc/src/osmo-nitb')
-rw-r--r--openbsc/src/osmo-nitb/bsc_hack.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/openbsc/src/osmo-nitb/bsc_hack.c b/openbsc/src/osmo-nitb/bsc_hack.c
index b74b71f14..86a36b793 100644
--- a/openbsc/src/osmo-nitb/bsc_hack.c
+++ b/openbsc/src/osmo-nitb/bsc_hack.c
@@ -368,8 +368,9 @@ int main(int argc, char **argv)
}
printf("DB: Database prepared.\n");
- /* Prepare HLR SUP socket if auth policy is "remote" */
- if (bsc_gsmnet->auth_policy == GSM_AUTH_POLICY_REMOTE) {
+ /* Prepare HLR SUP socket if auth policy is "remote" or "remote-closed"*/
+ if (bsc_gsmnet->auth_policy == GSM_AUTH_POLICY_REMOTE ||
+ bsc_gsmnet->auth_policy == GSM_AUTH_POLICY_REMOTE_CLOSED) {
bsc_gsmnet->hlr_sup_client = gprs_gsup_client_create(
"127.0.0.1", 8183,
&sup_read_cb);